==> dart_telegram_bot-0.6.1.tar.gz: lib/telegram_entities.dart <==
export 'src/entities/internal/entities/chat_id.dart';
export 'src/entities/internal/entities/http_file.dart';
export 'src/entities/internal/helpers/bot_command_parser.dart';
export 'src/entities/telegram/animation.dart';
export 'src/entities/telegram/audio.dart';
export 'src/entities/telegram/bot_command.dart';
export 'src/entities/telegram/bot_command_scope.dart';
export 'src/entities/telegram/bot_command_scope_all_chat_administrators.dart';
export 'src/entities/telegram/bot_command_scope_all_group_chats.dart';
export 'src/entities/telegram/bot_command_scope_all_private_chats.dart';
export 'src/entities/telegram/bot_command_scope_chat.dart';
export 'src/entities/telegram/bot_command_scope_chat_administrators.dart';
export 'src/entities/telegram/bot_command_scope_chat_member.dart';
export 'src/entities/telegram/bot_command_scope_default.dart';
export 'src/entities/telegram/callback_game.dart';
export 'src/entities/telegram/callback_query.dart';
export 'src/entities/telegram/chat.dart';
export 'src/entities/telegram/chat_invite_link.dart';
export 'src/entities/telegram/chat_location.dart';
export 'src/entities/telegram/chat_member.dart';
export 'src/entities/telegram/chat_member_updated.dart';
export 'src/entities/telegram/chat_permissions.dart';
export 'src/entities/telegram/chat_photo.dart';
export 'src/entities/telegram/chosen_inline_result.dart';
export 'src/entities/telegram/contact.dart';
export 'src/entities/telegram/document.dart';
export 'src/entities/telegram/encrypted_credentials.dart';
export 'src/entities/telegram/encrypted_passport_element.dart';
export 'src/entities/telegram/enums.dart';
export 'src/entities/telegram/file.dart';
export 'src/entities/telegram/force_reply.dart';
export 'src/entities/telegram/game.dart';
export 'src/entities/telegram/inline_keyboard_button.dart';
export 'src/entities/telegram/inline_keyboard_markup.dart';
export 'src/entities/telegram/inline_query.dart';
export 'src/entities/telegram/inline_query_result.dart';
export 'src/entities/telegram/inline_query_result_article.dart';
export 'src/entities/telegram/inline_query_result_audio.dart';
export 'src/entities/telegram/inline_query_result_cached_audio.dart';
export 'src/entities/telegram/inline_query_result_cached_document.dart';
export 'src/entities/telegram/inline_query_result_cached_gif.dart';
export 'src/entities/telegram/inline_query_result_cached_mpeg4_gif.dart';
export 'src/entities/telegram/inline_query_result_cached_photo.dart';
export 'src/entities/telegram/inline_query_result_cached_sticker.dart';
export 'src/entities/telegram/inline_query_result_cached_video.dart';
export 'src/entities/telegram/inline_query_result_cached_voice.dart';
export 'src/entities/telegram/inline_query_result_contact.dart';
export 'src/entities/telegram/inline_query_result_document.dart';
export 'src/entities/telegram/inline_query_result_game.dart';
export 'src/entities/telegram/inline_query_result_gif.dart';
export 'src/entities/telegram/inline_query_result_location.dart';
export 'src/entities/telegram/inline_query_result_mpeg4_gif.dart';
export 'src/entities/telegram/inline_query_result_photo.dart';
export 'src/entities/telegram/inline_query_result_venue.dart';
export 'src/entities/telegram/inline_query_result_video.dart';
export 'src/entities/telegram/inline_query_result_voice.dart';
export 'src/entities/telegram/input_media.dart';
export 'src/entities/telegram/input_media_animation.dart';
export 'src/entities/telegram/input_media_audio.dart';
export 'src/entities/telegram/input_media_document.dart';
export 'src/entities/telegram/input_media_photo.dart';
export 'src/entities/telegram/input_media_video.dart';
export 'src/entities/telegram/input_message_content.dart';
export 'src/entities/telegram/input_text_message_content.dart';
export 'src/entities/telegram/invoice.dart';
export 'src/entities/telegram/keyboard_button.dart';
export 'src/entities/telegram/keyboard_button_poll_type.dart';
export 'src/entities/telegram/labeled_price.dart';
export 'src/entities/telegram/location.dart';
export 'src/entities/telegram/login_url.dart';
export 'src/entities/telegram/mask_position.dart';
export 'src/entities/telegram/message.dart';
export 'src/entities/telegram/message_auto_delete_timer_changed.dart';
export 'src/entities/telegram/message_entity.dart';
export 'src/entities/telegram/message_id.dart';
export 'src/entities/telegram/order_info.dart';
export 'src/entities/telegram/passport_data.dart';
export 'src/entities/telegram/passport_data.dart';
export 'src/entities/telegram/passport_file.dart';
export 'src/entities/telegram/photo_size.dart';
export 'src/entities/telegram/poll.dart';
export 'src/entities/telegram/poll_answer.dart';
export 'src/entities/telegram/poll_option.dart';
export 'src/entities/telegram/pre_checkout_query.dart';
export 'src/entities/telegram/reply_keyboard_markup.dart';
export 'src/entities/telegram/reply_keyboard_remove.dart';
export 'src/entities/telegram/reply_markup.dart';
export 'src/entities/telegram/response_parameters.dart';
export 'src/entities/telegram/shipping_address.dart';
export 'src/entities/telegram/shipping_option.dart';
export 'src/entities/telegram/shipping_query.dart';
export 'src/entities/telegram/sticker.dart';
export 'src/entities/telegram/sticker_set.dart';
export 'src/entities/telegram/successful_payment.dart';
export 'src/entities/telegram/update.dart';
export 'src/entities/telegram/user.dart';
export 'src/entities/telegram/user_profile_photos.dart';
export 'src/entities/telegram/venue.dart';
export 'src/entities/telegram/video.dart';
export 'src/entities/telegram/video_note.dart';
export 'src/entities/telegram/voice.dart';
export 'src/entities/telegram/voice_chat_ended.dart';
export 'src/entities/telegram/voice_chat_started.dart';

==> dart_telegram_bot-0.7.0-b3.tar.gz: lib/telegram_entities.dart <==
export 'src/entities/internal/entities/chat_id.dart';
export 'src/entities/internal/entities/http_file.dart';
export 'src/entities/internal/helpers/bot_command_parser.dart';
export 'src/entities/telegram/animation.dart';
export 'src/entities/telegram/audio.dart';
export 'src/entities/telegram/bot_command.dart';
export 'src/entities/telegram/bot_command_scope.dart';
export 'src/entities/telegram/bot_command_scope_all_chat_administrators.dart';
export 'src/entities/telegram/bot_command_scope_all_group_chats.dart';
export 'src/entities/telegram/bot_command_scope_all_private_chats.dart';
export 'src/entities/telegram/bot_command_scope_chat.dart';
export 'src/entities/telegram/bot_command_scope_chat_administrators.dart';
export 'src/entities/telegram/bot_command_scope_chat_member.dart';
export 'src/entities/telegram/bot_command_scope_default.dart';
export 'src/entities/telegram/callback_game.dart';
export 'src/entities/telegram/callback_query.dart';
export 'src/entities/telegram/chat.dart';
export 'src/entities/telegram/chat_invite_link.dart';
export 'src/entities/telegram/chat_join_request.dart';
export 'src/entities/telegram/chat_location.dart';
export 'src/entities/telegram/chat_member.dart';
export 'src/entities/telegram/chat_member_updated.dart';
export 'src/entities/telegram/chat_permissions.dart';
export 'src/entities/telegram/chat_photo.dart';
export 'src/entities/telegram/chosen_inline_result.dart';
export 'src/entities/telegram/contact.dart';
export 'src/entities/telegram/dice.dart';
export 'src/entities/telegram/document.dart';
export 'src/entities/telegram/encrypted_credentials.dart';
export 'src/entities/telegram/encrypted_passport_element.dart';
export 'src/entities/telegram/enums.dart';
export 'src/entities/telegram/file.dart';
export 'src/entities/telegram/force_reply.dart';
export 'src/entities/telegram/game.dart';
export 'src/entities/telegram/game_high_score.dart';
export 'src/entities/telegram/inline_keyboard_button.dart';
export 'src/entities/telegram/inline_keyboard_markup.dart';
export 'src/entities/telegram/inline_query.dart';
export 'src/entities/telegram/inline_query_result.dart';
export 'src/entities/telegram/inline_query_result_article.dart';
export 'src/entities/telegram/inline_query_result_audio.dart';
export 'src/entities/telegram/inline_query_result_cached_audio.dart';
export 'src/entities/telegram/inline_query_result_cached_document.dart';
export 'src/entities/telegram/inline_query_result_cached_gif.dart';
export 'src/entities/telegram/inline_query_result_cached_mpeg4_gif.dart';
export 'src/entities/telegram/inline_query_result_cached_photo.dart';
export 'src/entities/telegram/inline_query_result_cached_sticker.dart';
export 'src/entities/telegram/inline_query_result_cached_video.dart';
export 'src/entities/telegram/inline_query_result_cached_voice.dart';
export 'src/entities/telegram/inline_query_result_contact.dart';
export 'src/entities/telegram/inline_query_result_document.dart';
export 'src/entities/telegram/inline_query_result_game.dart';
export 'src/entities/telegram/inline_query_result_gif.dart';
export 'src/entities/telegram/inline_query_result_location.dart';
export 'src/entities/telegram/inline_query_result_mpeg4_gif.dart';
export 'src/entities/telegram/inline_query_result_photo.dart';
export 'src/entities/telegram/inline_query_result_venue.dart';
export 'src/entities/telegram/inline_query_result_video.dart';
export 'src/entities/telegram/inline_query_result_voice.dart';
export 'src/entities/telegram/input_contact_message_content.dart';
export 'src/entities/telegram/input_location_message_content.dart';
export 'src/entities/telegram/input_media.dart';
export 'src/entities/telegram/input_media_animation.dart';
export 'src/entities/telegram/input_media_audio.dart';
export 'src/entities/telegram/input_media_document.dart';
export 'src/entities/telegram/input_media_photo.dart';
export 'src/entities/telegram/input_media_video.dart';
export 'src/entities/telegram/input_message_content.dart';
export 'src/entities/telegram/input_text_message_content.dart';
export 'src/entities/telegram/input_venue_message_content.dart';
export 'src/entities/telegram/invoice.dart';
export 'src/entities/telegram/keyboard_button.dart';
export 'src/entities/telegram/keyboard_button_poll_type.dart';
export 'src/entities/telegram/labeled_price.dart';
export 'src/entities/telegram/location.dart';
export 'src/entities/telegram/login_url.dart';
export 'src/entities/telegram/mask_position.dart';
export 'src/entities/telegram/message.dart';
export 'src/entities/telegram/message_auto_delete_timer_changed.dart';
export 'src/entities/telegram/message_entity.dart';
export 'src/entities/telegram/message_id.dart';
export 'src/entities/telegram/order_info.dart';
export 'src/entities/telegram/passport_data.dart';
export 'src/entities/telegram/passport_data.dart';
export 'src/entities/telegram/passport_file.dart';
export 'src/entities/telegram/photo_size.dart';
export 'src/entities/telegram/poll.dart';
export 'src/entities/telegram/poll_answer.dart';
export 'src/entities/telegram/poll_option.dart';
export 'src/entities/telegram/pre_checkout_query.dart';
export 'src/entities/telegram/proximity_alert_triggered.dart';
export 'src/entities/telegram/reply_keyboard_markup.dart';
export 'src/entities/telegram/reply_keyboard_remove.dart';
export 'src/entities/telegram/reply_markup.dart';
export 'src/entities/telegram/response_parameters.dart';
export 'src/entities/telegram/shipping_address.dart';
export 'src/entities/telegram/shipping_option.dart';
export 'src/entities/telegram/shipping_query.dart';
export 'src/entities/telegram/sticker.dart';
export 'src/entities/telegram/sticker_set.dart';
export 'src/entities/telegram/successful_payment.dart';
export 'src/entities/telegram/update.dart';
export 'src/entities/telegram/user.dart';
export 'src/entities/telegram/user_profile_photos.dart';
export 'src/entities/telegram/venue.dart';
export 'src/entities/telegram/video.dart';
export 'src/entities/telegram/video_note.dart';
export 'src/entities/telegram/voice.dart';
export 'src/entities/telegram/video_chat_ended.dart';
export 'src/entities/telegram/video_chat_participants_invited.dart';
export 'src/entities/telegram/video_chat_scheduled.dart';
export 'src/entities/telegram/video_chat_started.dart';
export 'src/entities/telegram/web_app_info.dart';
export 'src/entities/telegram/sent_web_app_message.dart';
export 'src/entities/telegram/web_app_data.dart';
export 'src/entities/telegram/menu_button.dart';
export 'src/entities/telegram/menu_button_commands.dart';
export 'src/entities/telegram/menu_button_web_app.dart';
export 'src/entities/telegram/menu_button_default.dart';
export 'src/entities/telegram/chat_administrator_rights.dart';
